@@ -3,7 +3,7 @@ use strict;
 
 package Mail::Box::MH::Index;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.063';
 use base 'Mail::Reporter';
 
 use Mail::Message::Head::Subset;
@@ -87,11 +87,14 @@ sub read(;$)
     my %index;
 
     while(my $head = $type->new(@options)->read($parser))
-    {   my $msgfile = $head->get('x-mailbox-filename');
+    {
+        # cleanup the index from files which were renamed
+        my $msgfile = $head->get('x-mailbox-filename');
         my $size    = int $head->get('x-mailbox-size');
         next unless -f $msgfile && -s _ == $size;
         next if defined $index_age && -M _ >= $index_age;
 
+        # keep this one
         $index{$msgfile} = $head;
     }
 
