@@ -1,9 +1,8 @@
-use strict;
 use warnings;
 
 package Mail::Message::Field::URIs;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.063';
 use base 'Mail::Message::Field::Structured';
 use Carp 'confess';
 
@@ -77,13 +76,4 @@ sub addAttribute($;@)
 #------------------------------------------
 
 
-sub addExtra($@)
-{   my $self = shift;
-    $self->log(ERROR => 'No extras in URI fields.');
-    $self;
-}
-
-#------------------------------------------
-
-
 1;
