@@ -3,7 +3,7 @@ use warnings;
 
 package Mail::Message::Wrapper::SpamAssassin;
 use vars '$VERSION';
-$VERSION = '2.060';
+$VERSION = '2.063';
 use base 'Mail::SpamAssassin::Message';
 
 use Carp;
@@ -17,7 +17,7 @@ sub new(@)    # fix missing infra-structure of base element
 
     $_->delete for $message->head->spamGroups('SpamAssassin');
 
-    $class->SUPER::new($message)->init(\%args);
+    $class->SUPER::new( {message => $message} )->init(\%args);
 }
 
 sub init($) { shift }
